#
# spec file for package lapack
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           lapack
Version:        3.5.0
Release:        lp150.3.3.1
Summary:        Linear Algebra Package
License:        BSD-3-Clause
Group:          Development/Libraries/Parallel
Url:            http://www.netlib.org/lapack/
Source0:        http://www.netlib.org/lapack/%{name}-%{version}.tgz
Source1:        lapack_testing.py
Source99:       baselibs.conf
Patch1:         lapack-3.2.2.patch
BuildRequires:  gcc-fortran
BuildRequires:  python3
BuildRequires:  update-alternatives
Requires(pre):  update-alternatives
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package     -n liblapack3
Summary:        LAPACK Shared Library
Group:          Development/Libraries/Parallel
%if 0%{?suse_version} >= 1120
Requires(pre):  update-alternatives
%endif

%description -n liblapack3
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package     -n libblas3
Summary:        BLAS Shared Library
Group:          Development/Libraries/Parallel
%if 0%{?suse_version} >= 1120
Requires(pre):  update-alternatives
%endif

%description -n libblas3
BLAS (Basic Linear Algebra Subprograms) is a standard library for
numerical algebra.  BLAS provides a number of basic algorithms for
linear algebra.

%package        devel
Summary:        Linear Algebra Package
Group:          Development/Libraries/Parallel
Requires:       blas-devel = %{version}
Requires:       liblapack3 = %{version}
Provides:       lapack = %{version}
Obsoletes:      lapack < %{version}

%description    devel
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package        devel-static
Summary:        Linear Algebra Package - static libraries
Group:          Development/Libraries/Parallel
Requires:       lapack-devel = %{version}

%description    devel-static
LAPACK provides routines for solving systems of simultaneous linear
equations, least-squares solutions of linear systems of equations,
eigenvalue problems, and singular value problems. The associated matrix
factorizations (LU, Cholesky, QR, SVD, Schur, generalized Schur) are
also provided, as are related computations such as reordering of the
Schur factorizations and estimating condition numbers. Dense and banded
matrices are handled, but not general sparse matrices. In all areas,
similar functionality is provided for real and complex matrices, in
both single and double precision.

%package     -n blas-devel
Summary:        Basic Linear Algebra Subprograms
Group:          Development/Libraries/Parallel
Requires:       libblas3 = %{version}
Provides:       blas = %{version}
Obsoletes:      blas < %{version}

%description -n blas-devel
BLAS (Basic Linear Algebra Subprograms) is a standard library for
numerical algebra. BLAS provides a number of basic algorithms for
linear algebra. BLAS is fast and well-tested, was written in FORTRAN 77
and built with gfortran. BLAS manual pages are available in the
blas-man package.

%package     -n blas-devel-static
Summary:        Basic Linear Algebra Subprograms
Group:          Development/Libraries/Parallel
Requires:       blas-devel = %{version}

%description -n blas-devel-static
BLAS (Basic Linear Algebra Subprograms) is a standard library for
numerical algebra. BLAS provides a number of basic algorithms for
linear algebra. BLAS is fast and well-tested, was written in FORTRAN 77
and built with gfortran. BLAS manual pages are available in the
blas-man package.

%package     -n liblapacke3
Summary:        LAPACKE development files
Group:          Development/Libraries/C and C++

%description -n liblapacke3
This library provides a native C interface to LAPACK routines available
at www.netlib.org/lapack to facilitate usage of LAPACK functionality
for C programmers.

This implementation introduces:
- row-major and column-major matrix layout controlled by the first function
  parameter;
- an implementation with working arrays (middle-level interface) as well as
  without working arrays (high-level interface);
- input scalars passed by value;
- error code as a return value instead of the INFO parameter.

%package     -n lapacke-devel
Summary:        LAPACKE development files
Group:          Development/Libraries/C and C++
Requires:       liblapacke3 = %{version}
Provides:       lapacke = %{version}
Provides:       lapacke-devel-static = %{version}

%description -n lapacke-devel
LAPACKE headers and development files.

%package     -n lapacke-devel-static
Summary:        LAPACKE development files - static libraries
Group:          Development/Libraries/C and C++
Requires:       lapacke-devel = %{version}

%description -n lapacke-devel-static
LAPACKE development files  - static libraries.

%prep
%setup -q
%patch1

%build
case "$RPM_ARCH" in
    i[0-9]86) PRECFLAGS="-ffloat-store" ;;
    *)        PRECFLAGS="" ;;
esac
export PRECFLAGS
cp make.inc.example make.inc
make cleanlib %{?_smp_mflags}
make %{?_smp_mflags} blaslib \
  OPTS="%{optflags} -fPIC" \
  NOOPT="%{optflags} -O0 -fPIC"
mv librefblas.a libblas_pic.a
mkdir tmp
( cd tmp; ar x ../libblas_pic.a )
gfortran -shared -Wl,-soname=libblas.so.3 -o libblas.so.%{version} tmp/*.o
ln -s libblas.so.%{version} libblas.so
rm -rf tmp
make cleanlib %{?_smp_mflags}
make %{?_smp_mflags} blaslib \
  OPTS="%{optflags}" \
  NOOPT="%{optflags} -O0"
make blas_testing \
  OPTS="%{optflags} $PRECFLAGS" \
  NOOPT="%{optflags} $PRECFLAGS -O0"
if grep -B15 -A15 FAIL BLAS/*.out; then
  echo
  echo "blas_testing FAILED"
  echo
  false
else
  true  # No failures
fi
mv librefblas.a libblas.a
make cleanlib %{?_smp_mflags}
make %{?_smp_mflags} lapacklib tmglib \
  OPTS="%{optflags} -fPIC" \
  NOOPT="%{optflags} -O0 -fPIC"
mv liblapack.a liblapack_pic.a
mv libtmglib.a libtmglib_pic.a
mkdir tmp
( cd tmp; ar x ../liblapack_pic.a; ar x ../libtmglib_pic.a )
gfortran -shared -Wl,-soname=liblapack.so.3 -o liblapack.so.%{version} tmp/*.o -L. -lblas
ln -s liblapack.so.%{version} liblapack.so
rm -rf tmp
make cleanlib %{?_smp_mflags}
make %{?_smp_mflags} lapacklib tmglib \
  OPTS="%{optflags}" \
  NOOPT="%{optflags} -O0"
mkdir tmp
( cd tmp; ar x ../libtmglib.a )
ar qs liblapack.a tmp/*.o
rm -rf tmp
ln -s libblas.a librefblas.a
cd lapacke
make %{?_smp_mflags} lapacke \
  CFLAGS="%{optflags} -fPIC -DADD_ -DHAVE_LAPACK_CONFIG_H -DLAPACK_COMPLEX_STRUCTURE" \
  LINKER=gfortran
mv ../liblapacke.a liblapacke_pic.a
mkdir tmp
( cd tmp; ar x ../liblapacke_pic.a )
gfortran -shared -Wl,-soname=liblapacke.so.3 -o liblapacke.so.%{version} tmp/*.o
ln -s liblapacke.so.%{version} liblapacke.so
rm -rf tmp
make cleanlib %{?_smp_mflags}
make %{?_smp_mflags} lapacke \
  CFLAGS="%{optflags} -DADD_ -DHAVE_LAPACK_CONFIG_H -DLAPACK_COMPLEX_STRUCTURE"
mv ../liblapacke.a liblapacke.a
# fix wrong end of line
sed -i 's/\r//' LICENSE
cd ..
cp %{SOURCE1} .
make lapack_testing \
  OPTS="%{optflags} $PRECFLAGS" \
  NOOPT="%{optflags} $PRECFLAGS -O0"
if grep -B15 -A15 FAIL TESTING/*.out; then
  echo
  echo "lapack_testing FAILED"
  echo
  false
else
  true  # No failures
fi

%install
install -d %{buildroot}/%{_libdir}
install -d %{buildroot}/%{_sysconfdir}/alternatives
## BLAS
install -d %{buildroot}/%{_libdir}/blas
install -m 644 libblas.a %{buildroot}/%{_libdir}
install -m 644 libblas_pic.a %{buildroot}/%{_libdir}
install -m 755 libblas.so.%{version} %{buildroot}/%{_libdir}/blas
ln -s libblas.so.%{version} %{buildroot}/%{_libdir}/blas/libblas.so.3
ln -s blas/libblas.so.%{version} %{buildroot}/%{_libdir}/libblas.so
# dummy target for update-alternatives
ln -s blas/libblas.so.%{version} %{buildroot}/%{_libdir}/libblas.so.3
ln -s libblas.so.%{version} %{buildroot}/%{_sysconfdir}/alternatives/libblas.so.3
## LAPACK
install -d %{buildroot}/%{_libdir}/lapack
install -m 644 liblapack.a %{buildroot}/%{_libdir}
install -m 644 liblapack_pic.a %{buildroot}/%{_libdir}
install -m 755 liblapack.so.%{version} %{buildroot}/%{_libdir}/lapack
ln -s liblapack.so.%{version} %{buildroot}/%{_libdir}/lapack/liblapack.so.3
ln -s lapack/liblapack.so.%{version} %{buildroot}/%{_libdir}/liblapack.so
# dummy target for update-alternatives
ln -s lapack/liblapack.so.%{version} %{buildroot}/%{_libdir}/liblapack.so.3
ln -s liblapack.so.%{version} %{buildroot}/%{_sysconfdir}/alternatives/liblapack.so.3
## LAPACKE
install -d %{buildroot}/%{_includedir}
cd lapacke
install -m 644 include/*.h %{buildroot}/%{_includedir}
install -m 644 liblapacke.a %{buildroot}/%{_libdir}
install -m 644 liblapacke_pic.a %{buildroot}/%{_libdir}
install -m 755 liblapacke.so.%{version} %{buildroot}/%{_libdir}
ln -s liblapacke.so.%{version} %{buildroot}/%{_libdir}/liblapacke.so.3
ln -s liblapacke.so.%{version} %{buildroot}/%{_libdir}/liblapacke.so
cd ..

%post -n libblas3
%{_sbindir}/update-alternatives --install \
   %{_libdir}/libblas.so.3 libblas.so.3 %{_libdir}/blas/libblas.so.3  50
/sbin/ldconfig

%preun -n libblas3
if [ "$1" = 0 ] ; then
   %{_sbindir}/update-alternatives --remove libblas.so.3  %{_libdir}/blas/libblas.so.3
fi

%postun -n libblas3 -p /sbin/ldconfig

%posttrans -n libblas3
if [ "$1" = 0 ] ; then
  if ! [ -f %{_libdir}/libblas.so.3 ] ; then
      "%{_sbindir}/update-alternatives" --auto libblas.so.3
  fi
fi

%post -n liblapack3
%{_sbindir}/update-alternatives --install \
   %{_libdir}/liblapack.so.3 liblapack.so.3 %{_libdir}/lapack/liblapack.so.3  50
/sbin/ldconfig

%preun -n liblapack3
if [ "$1" = 0 ] ; then
   %{_sbindir}/update-alternatives --remove liblapack.so.3 %{_libdir}/lapack/liblapack.so.3
fi

%postun -n liblapack3 -p /sbin/ldconfig

%posttrans -n liblapack3
if [ "$1" = 0 ] ; then
  if ! [ -f %{_libdir}/liblapack.so.3 ] ; then
      "%{_sbindir}/update-alternatives" --auto liblapack.so.3
  fi
fi

%post -n liblapacke3 -p /sbin/ldconfig

%postun -n liblapacke3 -p /sbin/ldconfig

%files -n liblapack3
%defattr(-,root,root)
%doc LICENSE README
%dir %{_libdir}/lapack
%{_libdir}/lapack/liblapack.so.%{version}
%{_libdir}/lapack/liblapack.so.3
%if 0%{?suse_version} >= 1120
%ghost %{_libdir}/liblapack.so.3
%ghost %{_sysconfdir}/alternatives/liblapack.so.3
%else
%{_libdir}/liblapack.so.3
%{_sysconfdir}/alternatives/liblapack.so.3
%endif

%files -n libblas3
%defattr(-,root,root)
%doc LICENSE README
%dir %{_libdir}/blas
%{_libdir}/blas/libblas.so.%{version}
%{_libdir}/blas/libblas.so.3
%if 0%{?suse_version} >= 1120
%ghost %{_libdir}/libblas.so.3
%ghost %{_sysconfdir}/alternatives/libblas.so.3
%else
%{_libdir}/libblas.so.3
%{_sysconfdir}/alternatives/libblas.so.3
%endif

%files devel
%defattr(-,root,root)
%{_libdir}/liblapack.so

%files devel-static
%defattr(-,root,root)
%{_libdir}/liblapack.a
%{_libdir}/liblapack_pic.a

%files -n blas-devel
%defattr(-,root,root)
%{_libdir}/libblas.so

%files -n blas-devel-static
%defattr(-,root,root)
%{_libdir}/libblas.a
%{_libdir}/libblas_pic.a

%files -n liblapacke3
%defattr(-,root,root,-)
%{_libdir}/liblapacke.so.%{version}
%{_libdir}/liblapacke.so.3

%files -n lapacke-devel
%defattr(-,root,root,-)
%doc lapacke/LICENSE lapacke/README
%{_libdir}/liblapacke.so
%{_includedir}/*.h

%files -n lapacke-devel-static
%defattr(-,root,root,-)
%{_libdir}/liblapacke.a
%{_libdir}/liblapacke_pic.a

%changelog
* Mon Apr  9 2018 rguenther@suse.com
- Build tmglib and fold contents into existing liblapack{.a,.so.3}.
  [bnc#1087426]
* Fri Jan 12 2018 rguenther@suse.com
- Package lapack_testing.py from lapack 3.8.0 with adjusted interpreter
  and adjust BuildRequires to python3.  [bnc#1075766]
* Wed May 31 2017 jengelh@inai.de
- Correct RPM groups
* Wed May 17 2017 dimstar@opensuse.org
- Build the man pages in a separate .spec file (lapack-man). The
  resulting rpm names are kept identical. This allows us to drop
  doxygen out of lapack's main package buildroot, thus eliminating
  a build cycle.
* Fri May  8 2015 dmitry_r@opensuse.org
- Fix static libraries list
* Wed Jul 16 2014 idonmez@suse.com
- Add baselibs.conf to sources
* Mon Jul 14 2014 toddrme2178@gmail.com
- Include update-alternatives dependency in subpackages that use it
  to guarantee it will be available.
* Wed Jun 18 2014 dmitry_r@opensuse.org
- Move blas and lapack libraries to subdirectories for fixing
  update-alternatives [bnc#861081]
- Add %%posttrans scripts for fixing migration problems.
* Thu Nov 21 2013 burnus@net-b.de
- Update to 3.5.0
  * Added Hermitian LDLT factorization routines with rook pivoting
    algorithm
  * 2-by-1 CSD to be used for tall and skinny matrix with orthonormal
    columns
  * New stopping criteria for balancing
  * New complex division algorithm
  * Various improvements
- No longer removing files due to license reasons as one file is
  no longer part of Lapack and the others have been replaced by
  new ones under the normal LAPACK license
* Tue Oct 29 2013 lnt-sysadmin@lists.lrz.de
- packaged symlinks created by update-alternative as %%ghost files
- removed quotes from update-alternative command to silence rpmlint warning
* Fri Mar 15 2013 dmitry_r@opensuse.org
- Split devel packages into devel and devel-static
* Sun Jan 13 2013 scorot@free.fr
- add update-alternative support to allow user to easily switch
  between several blas and lapack libraries
* Tue Nov  6 2012 burnus@net-b.de
- Update to 3.4.2
  * Bug fixes
* Wed Jul 25 2012 idonmez@suse.com
- Fix bnc#772628
* Thu Jul 19 2012 scorot@free.fr
- update baselibs.conf
* Sun Jul 15 2012 scorot@free.fr
- build the c interface lapacke
* Thu May 31 2012 kukuk@suse.de
- doxygen >= 1.7 is required for building docu
* Mon May 21 2012 saschpe@suse.de
- Change obsoletes '<=' for lapack and blas back to '<', there was a
  version update in between
- Remove psfig.tex (bnc#757332)
* Wed May  9 2012 coolo@suse.com
- fixing dependencies for devel-32bit
* Fri May  4 2012 burnus@net-b.de
- Update to 3.4.1
  * Bug fixes
* Mon Apr  2 2012 rguenther@suse.com
- Undo spec file obfuscation
* Fri Mar 30 2012 toddrme2178@gmail.com
- Fixed building on openSUSE 11.4 by fixing defattr
- Made the package groups consistent: Development/Libraries/Parallel
- Cleaned up spec file formatting
- Made all requires use the new package naming
* Wed Mar 14 2012 saschpe@suse.de
- Adhere to shared library policy, packages containing *.so or *.h
  files have to be named $FOO-devel, packages containing *.a files either
  have to be named $FOO-devel-static or provide this name
- Set license to 'BSD-3-Clause', according to the file LICENSE and the
  description on http://www.netlib.org/lapack/ it's not public domain
- Package README and LICENSE in library packages
- Removed rpmlint filters
- Use upstream tarball URL
* Mon Feb 13 2012 coolo@suse.com
- patch license to follow spdx.org standard
* Wed Nov 23 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
- Use %%_smp_mflags for parallel building
* Wed Nov 16 2011 burnus@net-b.de
- Update to 3.4.0
  * xGEQRT: QR factorization (improved interface)
  * xGEQRT3: recursive QR factorization.
  * xTPQRT: Communication-Avoiding QR sequential kernels.
  * Bug fixes.
  * Changes see http://www.netlib.org/lapack/lapack-3.4.0.html
* Fri Sep  9 2011 burnus@net-b.de
- Run BLAS and LAPACK testsuite when building
* Thu May 12 2011 burnus@net-b.de
- Update to 3.3.1 [bnc#654560]
  * New procedures to compute the complete CS decomposition of a
    partitioned unitary matrix
  * Level-3 BLAS symmetric indefinite solve (xSYTRS) and symmetric
    indefinite inversion (xSYTRI)
  * Bug fixes
  * Changes see at http://www.netlib.org/lapack/lapack-3.3.1.html
    and http://www.netlib.org/lapack/lapack-3.3.0.html
* Thu Aug 12 2010 rguenther@novell.com
- Add baselibs.  [bnc#630656]
* Thu Jul  8 2010 burnus@net-b.de
- Update to version 3.2.2
  * Bug fix release
  * Changes see at http://www.netlib.org/lapack/lapack-3.2.2.html
* Tue Feb  9 2010 prusnak@suse.cz
- package man and blas-man as noarch
* Wed Jan 13 2010 rguenther@suse.de
- Drop -O3 -funroll-all-loops compiler flags, build dcabs1.f with -O0.
  [bnc#569978]
* Mon May 18 2009 dominique-obs@leuenberger.net
- Update to version 3.2.1 [bnc#504669]
  * Changes see at http://www.netlib.org/lapack/lapack-3.2.1.html
* Wed Jan 28 2009 rguenther@suse.de
- Update to version 3.2.0.  [bnc#456384]
  * Extra Precise Iterative Refinement
  * XBLAS
  * Non-Negative Diagonals from Householder QR
  * High Performance QR and Householder Reflections on Low-Profile Matrices
  * New fast and accurate Jacobi SVD
  * Routines for Rectangular Full Packed format
  * Pivoted Cholesky
  * Mixed precision iterative refinement
  * Some new variants added for the one sided factorization
  * More robust DQDS algorithm
* Sun May 11 2008 lrupp@suse.de
- use versioned requires/obsoletes
- %%run_ldconfig is deprecated
- prefix the patch with the packagename
* Fri Apr 27 2007 rguenther@suse.de
- Update to version 3.1.1.  [#265999]
- Integrates 3.1.0 errata and missing blas routines.
- Provides better gfortran SECOND integration.
- Split shared libraries into their own versioned subpackage.
* Fri Jan 19 2007 rguenther@suse.de
- Include fixes for the 3.1.0 errata.
- Add missing CSROT, DROTM, DROTMG, DSDOT, SDSDOT, SROTM, SROTMG
  and ZDROT from blas distribution.  [#228824]
* Thu Dec 14 2006 rguenther@suse.de
- Restore missing so symlinks.
* Tue Nov 14 2006 rguenther@suse.de
- Update to version 3.1.0.
- Rename blasman to blas-man.
- Rename lapack-manpages to lapack-man.
* Tue Oct 31 2006 rguenther@suse.de
- Trim BuildRequires.
- Build and package -fPIC static library variants.  [#205310]
- Fix installing of the libblas.so symlink.
- Do not package the matrix testing setup library libtmglib.
- Do not package useless README file.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Fri Apr 22 2005 meissner@suse.de
- fixed all other instances of -fno-f2c, and g77 -> gfortran use.
* Thu Apr 21 2005 meissner@suse.de
- g77 -> gfortran, -fno-f2c is no more.
* Sat Jan 29 2005 nashif@suse.de
- Updated manpages (#48784)
* Thu Jan 20 2005 ro@suse.de
- remove BuildPrereq, BuildRequires is generated
* Thu Mar 18 2004 nashif@suse.de
- Fixed permission for manpages (#36340)
* Sat Jan 10 2004 adrian@suse.de
- add %%run_ldconfig
* Mon Feb  3 2003 meissner@suse.de
- Use $RPM_OPT_FLAGS, so it builds on ppc64.
* Mon Aug 26 2002 nashif@suse.de
- Fixed manpage conflict
- correct library version
* Mon Jul  1 2002 ro@suse.de
- use -fPIC for all shared objects
- link liblapack with shared libblas (same reason)
* Thu May  2 2002 sf@suse.de
- fixed %%{_lib}-problems for x86_64
* Mon Sep 17 2001 nashif@suse.de
-  Fixed bug #9925, adding blas to required packages.
* Tue May  8 2001 nashif@suse.de
-  Fixed bug #6803
* Thu Feb  8 2001 sf@suse.de
- compile with '-01' for IA64 due to 'internal compiler error' in g77
* Mon Nov  6 2000 nashif@suse.de
-  Fixed bug of missing objects (#4028)
* Fri Apr 21 2000 nashif@suse.de
-  Applied new patches
-  Modified group, url and files in spec
* Mon Feb 21 2000 nashif@suse.de
-   Applied new patches
* Tue Jan 18 2000 nashif@suse.de
-   Applied new patched
-   Moved manpages to /usr/share/man
* Thu Dec 23 1999 nashif@suse.de
-    Update to latest version
-    Package split lapack + blas
* Thu Oct  7 1999 nashif@suse.de
- Package split: man pages + libraries
* Wed Sep 22 1999 nashif@suse.de
- New package: LAPACK
  Linear Algebra Package (LAPACK)
